@@ -50,6 +50,9 @@ class http_server:
         except NotImplementedError:
             pass
 
+        start_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+        print(f"Server start at {g_server.host}:{g_server.port} at {start_time}")
+
         while self.running:
             pre = time.time()
             for f in self.update_list:
